=======
History
=======


0.2.1 (2019-11-30)
------------------

* Fix issues with version numbering in ``setup.py``

0.2.0 (2019-11-30)
------------------

* Implement basic API client.
* Implement API route ``api_list_core_versions`` as method on API client.
* Update documentation.
* Deprecate Python 3.5 and 3.6 (because f-strings and data classes!)

0.1.0 (2019-11-28)
------------------

* First release on PyPI.
